
# Slot: object


gene implicated in genotype

URI: [biolink:genotype_to_gene_association_object](https://w3id.org/biolink/vocab/genotype_to_gene_association_object)


## Domain and Range

[GenotypeToGeneAssociation](GenotypeToGeneAssociation.md) &#8594;  <sub>1..1</sub> [Gene](Gene.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [GenotypeToGeneAssociation](GenotypeToGeneAssociation.md)
